#
# spec file for package iftop
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         pkg_version 1.0pre4
Name:           iftop
Version:        0.99.4
Release:        10.3
Summary:        Real-Time Interface Bandwidth Usage
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Diagnostic
URL:            https://www.ex-parrot.com/~pdw/iftop/
Source0:        https://www.ex-parrot.com/~pdw/iftop/download/iftop-%{pkg_version}.tar.gz
Patch0:         MAC-address-format.patch
Patch1:         001-Avoid-32-bit-overflow-for-rates-when-calculating-bar.patch
Patch2:         002-scale-up-to-tbit.patch
Patch3:         003-rateidx_init-fix.patch
Patch4:         004-iftop-unlimited_text_output.patch
Patch5:         0001-Prefer-ncurses6w.patch
Patch6:         006-iftop-choose_first_running_interface.patch
Patch7:         007-iftop-declare-extern-vars.patch
BuildRequires:  automake
BuildRequires:  libpcap-devel
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(ncursesw)
%else
BuildRequires:  ncurses-devel
%endif

%description
iftop does for network usage what top(1) does for CPU usage. It listens
to network traffic on a named interface and displays a table of current
bandwidth usage by pairs of hosts. It is handy for explaining why the
network links slow.

%prep
%setup -q -n %{name}-%{pkg_version}
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%if 0%{?suse_version} >= 1500
%patch -P 5 -p1
%endif
%patch -P 6 -p1
%if 0%{?suse_version} >= 1500
%patch -P 7 -p1
%endif

%build
autoreconf -fiv
%configure
%make_build %{?smp_mflags} CPPFLAGS=-DUSE_GETIFADDRS

%install
%make_install

%files
%license COPYING
%doc README ChangeLog TODO
%{_sbindir}/iftop
%{_mandir}/man8/iftop.8%{?ext_man}

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Apr 21 2021 Dirk Müller <dmueller@suse.com>
- spec-cleaner run (move license to licensedir)
  * use https for urls
* Fri Jul 10 2020 Brice DEKANY <brice.dekany@suse.com>
- added 007-iftop-declare-extern-vars.patch: fix for compilations
  error with GCC10 (Default to -fno-common)
  See: https://www.gnu.org/software/gcc/gcc-10/porting_to.html
* Thu Apr 11 2019 lars@linux-schulserver.de - 0.99.4
- added 006-iftop-choose_first_running_interface.patch:
  Choose first running interface, rather than first "up" interface
- apply/use 0001-Prefer-ncurses6w.patch only on newer distributions
* Thu Jan  3 2019 Cristian Rodríguez <crrodriguez@opensuse.org>
- 0001-Prefer-ncurses6w.patch: prefer ncursesw6, previously force-fed
  via CFLAGS/LDFLAGS but did not really work.
* Wed Apr 30 2014 lars@linux-schulserver.de
- fix bnc#875625: iftop 0.99.2 memory leakeage
- added MAC-address-format.patch : defining the MAC address of the
  interface as char instead of integer, which results in correct
  commandline output
  http://lists.beasts.org/pipermail/iftop-users/2014-March/000413.html
- added 001-Avoid-32-bit-overflow-for-rates-when-calculating-bar.patch
  http://lists.beasts.org/pipermail/iftop-users/2014-March/000414.html
- added 002-scale-up-to-tbit.patch : Extend the scale[] array up to
  terabit. 10gbit is not uncommon, 100gbit 40 and 100 gbit are coming,
  400 gbit and terabit are future possibilities.
- 003-rateidx_init-fix.patch : When calculating the first rateidx,
  we were overshooting to the next scale. Fix that.
- 004-iftop-unlimited_text_output.patch : Allow unlimited number of
  lines in text output, using "iftop -t -L 0"
* Fri Feb 14 2014 andreas.stieger@gmx.de
- update to 1.0pre4:
  * Man page documentation of -t mode.
  * Compile time warning fixes.
- removed patches:
  * iftop-implicit-pointer-decl.patch
- remove autoconf calls previously required
* Fri Jan  3 2014 pascal.bleser@opensuse.org
- update to 1.0pre3:
  * bugs and compilation issues were fixed
  * a "text output" mode was added.
- drop the following patches, merged upstream:
  * iftop-manpage.patch
  * iftop-multicast.patch
* Tue Mar  5 2013 crrodriguez@opensuse.org
- Use ncursesw6
- fix a number of implicit declarations and
  implicit-pointer-decl warnings (iftop-implicit-pointer-decl.patch)
* Sun Nov 25 2012 schwab@linux-m68k.org
- Properly handle multicast packages
- Define USE_GETIFADDRS to use getifaddrs for better IPv6 support
* Mon Apr  2 2012 andreas.stieger@gmx.de
- update to 1.0pre2:
  * reverse IPv6 using all methods except ares
  * faster switching of graph scale
  * fixed support for DLT_NULL
  * fix for segfault on interfaces with no MAC address
  * improved interface autodetect
  * a stab at implementing support for radiotap interfaces (DLT 127).
- updated iftop-manpage.patch to fix manpage formatting warning
- remove INSTALL from installed files
- removed revious source
- removed iftop-1.0-includes_fix.patch
- removed counter_hash.h
* Mon Apr 11 2011 lars@linux-schulserver.de
- update to 1.0pre1:
  + Support for IPv6
  + Various typos fixed
  + documentation fixed
  + Fixed behaviour of "-b" option
  + Support for PFLOG Interfaces
  + Fix for performance issue with address hashing
  + Fix for failing link address detection for GNU/kfreebsd
  + Improved behaviour of sort in sent/recv only mode
  + Fixed segfault / hang when supplying multiple -i options
- removed upstreamed patches
* Sun Nov 29 2009 lrupp@suse.de
- added iftop-bar-bytes.patch and iftop-bar-display.patch from
  Debian
- enhanced the iftop-manpage.patch
- small specfile cleanup
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Thu Jul 26 2007 prusnak@suse.cz
- changed libpcap to libpcap-devel in BuildRequires
* Thu Mar 29 2007 rguenther@suse.de
- add ncurses-devel BuildRequires
* Mon Jul 10 2006 mskibbe@suse.de
- update to version 0.17 which
  o Added support for ppp interfaces
  o Fixed segfault bug in config file handling
  o Fixes to man page
  o Fix for hash table memory handling bug
  o Added 802.1q VLAN support
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 12 2005 hvogel@suse.de
- Add -fno-strict-aliasing
* Wed Mar  9 2005 hvogel@suse.de
- add '-m' parameter to manpage
* Mon Mar  1 2004 hvogel@suse.de
- update to version 0.16 which includes all fixes from mmj
* Wed Feb  4 2004 mmj@suse.de
- Fix dereferencing of type-punned pointers
* Thu Jan 29 2004 hvogel@suse.de
- mark man pages as documentation
* Mon Jan 26 2004 hvogel@suse.de
- do not use %%configure macro
- use CFLAGS
* Wed Jan 21 2004 mmj@suse.de
- Fix compound statement to work with new gcc-3.4
* Tue Jan 20 2004 hvogel@suse.de
- first build and release. Version 0.15
